@@ -3,6 +3,7 @@ import string
 from django.db.models import Q
 
 from django.views.generic.list_detail import object_list
+from django.db import connection, transaction
 
 from glossary.models import Term
 
@@ -30,5 +31,20 @@ def term_list(request, **kwargs):
         terms = terms.filter(title__istartswith=ec['starts_with'])
 
     terms = terms.extra(select={"lower_title": "LOWER(%s.title)" % Term._meta.db_table }).order_by("lower_title")
+    
+    used_letters = []
+    for i in ec["a_z"]:
+        try:
+            x = Term.objects.get(title__startswith=i)
+            used_letters.append(i)
+        except:
+            pass
+    
 
-    return object_list(request, queryset=terms, extra_context=ec, **kwargs)
+    return object_list(request, 
+                        queryset=terms, 
+                        extra_context={'ec': ec,
+                                        'starts_with': ec['starts_with'],
+                                        'a_z': ec['a_z'],
+                                        'used_letters': used_letters},
+                        **kwargs)
